==> deepin-calculator_6.0.1.tar.xz: BUILD/translations/deepin-calculator_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Помилка у виразі</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>Спорожнити усю пам&apos;ять</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Спорожнити журнал</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Позначити все</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Повторити</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Вирізати</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставити</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>Калькулятор</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>Стандартний</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>Науковий</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>«Калькулятор» є простим у користуванні комп&apos;ютерним калькулятором. Передбачено підтримку стандартного, наукового та програмістського режимів.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>Програмістський</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>Спорожнити запис пам&apos;яті</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>Спорожнити усю пам&apos;ять</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>Відновлення з пам&apos;яті</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Додати до запису пам&apos;яті</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>Додати до пам&apos;яті</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Відняти від запису пам&apos;яті</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>Відняти від пам&apos;яті</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>Зберегти у пам&apos;яті</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Запам&apos;ятати</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>Спорожнити запис пам&apos;яті</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Додати до запису пам&apos;яті</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Відняти від запису пам&apos;яті</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>У пам&apos;яті нічого не збережено</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Помилка у виразі</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Арифметичний зсув</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Логічний зсув</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Циклічний зсув</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Циклічний зсув, обертання з перенесенням</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Арифметичний зсув</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Логічний зсув</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Циклічний зсув</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Циклічний зсув, обертання з перенесенням</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>Калькулятор</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Помилка у виразі</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>Журнал</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Запам&apos;ятати</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>Помилка у виразі</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>Немає журналу</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
</context>
</TS>

==> deepin-calculator_6.5.12.tar.xz: BUILD/translations/deepin-calculator_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Помилка у виразі</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>Спорожнити усю пам&apos;ять</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Спорожнити журнал</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Позначити все</translation>
    </message>
    <message>
        <source>Use thousands separator</source>
        <translation>Роздільник тисяч</translation>
    </message>
    <message>
        <source>Use ten-thousands separator</source>
        <translation>Роздільник десятків тисяч</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Повторити</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Вирізати</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставити</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>Калькулятор</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>Стандартний</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>Науковий</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>«Калькулятор» є простим у користуванні комп&apos;ютерним калькулятором. Передбачено підтримку стандартного, наукового та програмістського режимів.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>Програмістський</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>Спорожнити запис пам&apos;яті</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>Спорожнити усю пам&apos;ять</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>Відновлення з пам&apos;яті</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Додати до запису пам&apos;яті</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>Додати до пам&apos;яті</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Відняти від запису пам&apos;яті</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>Відняти від пам&apos;яті</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>Зберегти у пам&apos;яті</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Запам&apos;ятати</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>Спорожнити запис пам&apos;яті</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Додати до запису пам&apos;яті</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Відняти від запису пам&apos;яті</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>У пам&apos;яті нічого не збережено</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Помилка у виразі</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Арифметичний зсув</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Логічний зсув</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Циклічний зсув</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Циклічний зсув, обертання з перенесенням</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Арифметичний зсув</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Логічний зсув</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Циклічний зсув</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Циклічний зсув, обертання з перенесенням</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>Калькулятор</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Помилка у виразі</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>Журнал</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Запам&apos;ятати</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>Помилка у виразі</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>Немає журналу</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
</context>
</TS>
